@@ -39,48 +39,38 @@ use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
 use Google::Ads::GoogleAds::Utils::SearchStreamHandler;
-use Google::Ads::GoogleAds::V12::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V12::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V12::Resources::UserList;
-use Google::Ads::GoogleAds::V12::Common::ExpressionRuleUserListInfo;
-use Google::Ads::GoogleAds::V12::Common::RuleBasedUserListInfo;
-use Google::Ads::GoogleAds::V12::Common::UserListInfo;
-use Google::Ads::GoogleAds::V12::Common::UserListRuleInfo;
-use Google::Ads::GoogleAds::V12::Common::UserListRuleItemInfo;
-use Google::Ads::GoogleAds::V12::Common::UserListRuleItemGroupInfo;
-use Google::Ads::GoogleAds::V12::Common::UserListStringRuleItemInfo;
-use Google::Ads::GoogleAds::V12::Enums::UserListMembershipStatusEnum qw(OPEN);
-use Google::Ads::GoogleAds::V12::Enums::UserListPrepopulationStatusEnum
+use Google::Ads::GoogleAds::V13::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V13::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V13::Resources::UserList;
+use Google::Ads::GoogleAds::V13::Common::FlexibleRuleOperandInfo;
+use Google::Ads::GoogleAds::V13::Common::FlexibleRuleUserListInfo;
+use Google::Ads::GoogleAds::V13::Common::RuleBasedUserListInfo;
+use Google::Ads::GoogleAds::V13::Common::UserListInfo;
+use Google::Ads::GoogleAds::V13::Common::UserListRuleInfo;
+use Google::Ads::GoogleAds::V13::Common::UserListRuleItemInfo;
+use Google::Ads::GoogleAds::V13::Common::UserListRuleItemGroupInfo;
+use Google::Ads::GoogleAds::V13::Common::UserListStringRuleItemInfo;
+use Google::Ads::GoogleAds::V13::Enums::UserListFlexibleRuleOperatorEnum
+  qw(AND);
+use Google::Ads::GoogleAds::V13::Enums::UserListMembershipStatusEnum qw(OPEN);
+use Google::Ads::GoogleAds::V13::Enums::UserListPrepopulationStatusEnum
   qw(REQUESTED);
-use Google::Ads::GoogleAds::V12::Enums::UserListStringRuleItemOperatorEnum
+use Google::Ads::GoogleAds::V13::Enums::UserListStringRuleItemOperatorEnum
   qw(CONTAINS);
 use
-  Google::Ads::GoogleAds::V12::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+  Google::Ads::GoogleAds::V13::Services::AdGroupCriterionService::AdGroupCriterionOperation;
 use
-  Google::Ads::GoogleAds::V12::Services::CampaignCriterionService::CampaignCriterionOperation;
+  Google::Ads::GoogleAds::V13::Services::CampaignCriterionService::CampaignCriterionOperation;
 use
-  Google::Ads::GoogleAds::V12::Services::GoogleAdsService::SearchGoogleAdsStreamRequest;
-use Google::Ads::GoogleAds::V12::Services::UserListService::UserListOperation;
-use Google::Ads::GoogleAds::V12::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V13::Services::GoogleAdsService::SearchGoogleAdsStreamRequest;
+use Google::Ads::GoogleAds::V13::Services::UserListService::UserListOperation;
+use Google::Ads::GoogleAds::V13::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
 use Cwd          qw(abs_path);
 use Data::Uniqid qw(uniqid);
 
-# The following parameter(s) should be provided to run the example. You can
-# either specify these by changing the INSERT_XXX_ID_HERE values below, or on
-# the command line.
-#
-# Parameters passed on the command line will override any parameters set in
-# code.
-#
-# Running the example with -h will print the command line usage.
-my $customer_id        = "INSERT_CUSTOMER_ID_HERE";
-my $ad_group_id        = "INSERT_AD_GROUP_ID_HERE";
-my $campaign_id        = "INSERT_CAMPAIGN_ID_HERE";
-my $bid_modifier_value = "INSERT_BID_MODIFIER_VALUE_HERE";
-
 sub set_up_remarketing {
   my ($api_client, $customer_id, $ad_group_id, $campaign_id,
     $bid_modifier_value)
@@ -118,35 +108,45 @@ sub create_user_list {
   my ($api_client, $customer_id) = @_;
 
   # Create a rule targeting any user that visited a url containing 'example.com'.
-  my $rule = Google::Ads::GoogleAds::V12::Common::UserListRuleItemInfo->new({
+  my $rule = Google::Ads::GoogleAds::V13::Common::UserListRuleItemInfo->new({
       # Use a built-in parameter to create a domain URL rule.
       name           => "url__",
       stringRuleItem =>
-        Google::Ads::GoogleAds::V12::Common::UserListStringRuleItemInfo->new({
+        Google::Ads::GoogleAds::V13::Common::UserListStringRuleItemInfo->new({
           operator => CONTAINS,
           value    => "example.com"
         })});
 
   # Specify that the user list targets visitors of a page based on the provided rule.
   my $user_list_rule_item_group_info =
-    Google::Ads::GoogleAds::V12::Common::UserListRuleItemGroupInfo->new(
+    Google::Ads::GoogleAds::V13::Common::UserListRuleItemGroupInfo->new(
     {ruleItems => [$rule]});
-  my $expression_rule_user_list_info =
-    Google::Ads::GoogleAds::V12::Common::ExpressionRuleUserListInfo->new({
-      rule => Google::Ads::GoogleAds::V12::Common::UserListRuleInfo->new({
-          ruleItemGroups => [$user_list_rule_item_group_info]})});
+  my $flexible_rule_user_list_info =
+    Google::Ads::GoogleAds::V13::Common::FlexibleRuleUserListInfo->new({
+      inclusiveRuleOperator => AND,
+      # Inclusive operands are joined together with the specified inclusiveRuleOperator.
+      inclusiveOperands => [
+        Google::Ads::GoogleAds::V13::Common::FlexibleRuleOperandInfo->new({
+            rule => Google::Ads::GoogleAds::V13::Common::UserListRuleInfo->new({
+                ruleItemGroups => [$user_list_rule_item_group_info]}
+            ),
+            # Optionally add a lookback window for this rule, in days.
+            lookbackWindowDays => 7
+          })
+      ],
+      exclusiveOperands => []});
 
   # Define a representation of a user list that is generated by a rule.
   my $rule_based_user_list_info =
-    Google::Ads::GoogleAds::V12::Common::RuleBasedUserListInfo->new({
+    Google::Ads::GoogleAds::V13::Common::RuleBasedUserListInfo->new({
       # Optional: To include past users in the user list, set the
       # prepopulationStatus to REQUESTED.
-      prepopulationStatus    => REQUESTED,
-      expressionRuleUserList => $expression_rule_user_list_info
+      prepopulationStatus  => REQUESTED,
+      flexibleRuleUserList => $flexible_rule_user_list_info
     });
 
   # Create the user list.
-  my $user_list = Google::Ads::GoogleAds::V12::Resources::UserList->new({
+  my $user_list = Google::Ads::GoogleAds::V13::Resources::UserList->new({
     name               => "All visitors to example.com #" . uniqid(),
     description        => "Any visitor to any page of example.com",
     membershipLifespan => 365,
@@ -156,7 +156,7 @@ sub create_user_list {
 
   # Create the operation.
   my $user_list_operation =
-    Google::Ads::GoogleAds::V12::Services::UserListService::UserListOperation->
+    Google::Ads::GoogleAds::V13::Services::UserListService::UserListOperation->
     new({
       create => $user_list
     });
@@ -182,17 +182,17 @@ sub target_ads_in_ad_group_to_user_list {
 
   # Create the ad group criterion targeting members of the user list.
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V12::Resources::AdGroupCriterion->new({
-      adGroup => Google::Ads::GoogleAds::V12::Utils::ResourceNames::ad_group(
+    Google::Ads::GoogleAds::V13::Resources::AdGroupCriterion->new({
+      adGroup => Google::Ads::GoogleAds::V13::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
-      userList => Google::Ads::GoogleAds::V12::Common::UserListInfo->new({
+      userList => Google::Ads::GoogleAds::V13::Common::UserListInfo->new({
           userList => $user_list_resource_name
         })});
 
   # Create the operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V12::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V13::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion
     });
@@ -222,14 +222,14 @@ sub modify_ad_group_bids {
   # Create the ad group criterion with a bid modifier. You may alternatively set
   # the bid for the ad group criterion directly.
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V12::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V13::Resources::AdGroupCriterion->new({
       resourceName => $ad_group_criterion_resource_name,
       bidModifier  => $bid_modifier_value
     });
 
   # Create the update operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V12::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V13::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       update     => $ad_group_criterion,
       updateMask => all_set_fields_of($ad_group_criterion)});
@@ -259,7 +259,7 @@ sub remove_existing_list_criteria_from_ad_group {
   foreach my $ad_group_criterion (@$ad_group_criteria) {
     push(
       @$operations,
-      Google::Ads::GoogleAds::V12::Services::AdGroupCriterionService::AdGroupCriterionOperation
+      Google::Ads::GoogleAds::V13::Services::AdGroupCriterionService::AdGroupCriterionOperation
         ->new({
           remove => $ad_group_criterion
         }));
@@ -291,7 +291,7 @@ sub get_user_list_ad_group_criteria {
   # Create a search stream request that will retrieve all of the user list ad
   # group criteria under a campaign.
   my $search_stream_request =
-    Google::Ads::GoogleAds::V12::Services::GoogleAdsService::SearchGoogleAdsStreamRequest
+    Google::Ads::GoogleAds::V13::Services::GoogleAdsService::SearchGoogleAdsStreamRequest
     ->new({
       customerId => $customer_id,
       query      => sprintf(
@@ -332,17 +332,17 @@ sub target_ads_in_campaign_to_user_list {
 
   # Create the campaign criterion.
   my $campaign_criterion =
-    Google::Ads::GoogleAds::V12::Resources::CampaignCriterion->new({
-      campaign => Google::Ads::GoogleAds::V12::Utils::ResourceNames::campaign(
+    Google::Ads::GoogleAds::V13::Resources::CampaignCriterion->new({
+      campaign => Google::Ads::GoogleAds::V13::Utils::ResourceNames::campaign(
         $customer_id, $campaign_id
       ),
-      userList => Google::Ads::GoogleAds::V12::Common::UserListInfo->new({
+      userList => Google::Ads::GoogleAds::V13::Common::UserListInfo->new({
           userList => $user_list_resource_name
         })});
 
   # Create the operation.
   my $campaign_criterion_operation =
-    Google::Ads::GoogleAds::V12::Services::CampaignCriterionService::CampaignCriterionOperation
+    Google::Ads::GoogleAds::V13::Services::CampaignCriterionService::CampaignCriterionOperation
     ->new({
       create => $campaign_criterion
     });
@@ -371,14 +371,14 @@ sub modify_campaign_bids {
 
   # Create the campaign criterion to update.
   my $campaign_criterion =
-    Google::Ads::GoogleAds::V12::Resources::CampaignCriterion->new({
+    Google::Ads::GoogleAds::V13::Resources::CampaignCriterion->new({
       resourceName => $campaign_criterion_resource_name,
       bidModifier  => $bid_modifier_value
     });
 
   # Create the update operation.
   my $campaign_criterion_operation =
-    Google::Ads::GoogleAds::V12::Services::CampaignCriterionService::CampaignCriterionOperation
+    Google::Ads::GoogleAds::V13::Services::CampaignCriterionService::CampaignCriterionOperation
     ->new({
       update     => $campaign_criterion,
       updateMask => all_set_fields_of($campaign_criterion)});
@@ -404,6 +404,11 @@ my $api_client = Google::Ads::GoogleAds::Client->new();
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
 
+my $customer_id        = undef;
+my $ad_group_id        = undef;
+my $campaign_id        = undef;
+my $bid_modifier_value = undef;
+
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
   "customer_id=s"        => \$customer_id,
